import { login } from '@/services/ant-design-pro/api';
import { getCaptchaId } from '@/services/ant-design-pro/login';
import { DefaultFooter } from '@ant-design/pro-components';
import { Button, Form, Input, message } from 'antd';
import React, { useEffect, useState } from 'react';
import { history, useModel } from 'umi';
import styles from './index.less';
import md5 from 'js-md5';

const FormItem = Form.Item;

/**
 *
 * @returns footer
 */
const Footer: React.FC = () => {
  const currentYear = new Date().getFullYear();
  const defaultMessage = '永续绿建web管理平台';
  return <DefaultFooter className={styles.footer} copyright={`${currentYear} ${defaultMessage}`} />;
};

const Login: React.FC = () => {
  const { initialState, setInitialState } = useModel('@@initialState');
  const [captcha_id, setCaptcha_id] = useState('');

  /**
   * 获取验证码id
   */
  const fetchCaptcha = () => {
    getCaptchaId().then(async (res) => {
      setCaptcha_id(res.captcha_id);
    });
  };

  /**
   * 初始化
   */
  useEffect(() => {
    fetchCaptcha();
  }, []);

  /**
   * 获取账号用户信息
   */
  const fetchUserInfo = async () => {
    const userInfo = await initialState?.fetchUserInfo?.();
    if (userInfo) {
      await setInitialState((s: any) => ({ ...s, currentUser: userInfo }));
    }
  };

  /**
   * 登录
   * @param values
   * @returns
   */
  const handleSubmit = async (values: API.LoginParams) => {
    try {
      const body = {
        ...values,
        password: md5(values.password),
        captcha_id,
      };
      const msg = await login(body);
      if (!msg?.error) {
        if (localStorage.getItem('token') == null || localStorage.getItem('token') == undefined) {
          localStorage.setItem('token', '');
        }
        localStorage.setItem('token', `${msg.token_type} ${msg.access_token}`);
        message.success(`欢迎登录系统`);
        await fetchUserInfo();
        history.push('/');
        if (!history) return;
        const { query } = history.location;
        const { redirect } = query as { redirect: string };
        history.push(redirect || '/');
      } else {
        message.error(msg?.error?.message || '登录失败');
      }
    } catch (error) {
      // const _ = fetchCaptcha();
      message.success(`登录失败`);
    }
  };

  return (
    <div className={styles.container}>
      <div className={styles.loginBox}>
        <img alt="请登录" src="/assets/login-left.png" className={styles.login_bg} />
        <div className={styles.main}>
          <div className={styles.title}>
            <img src="/assets/logo.png" alt="logo" className={styles.logoStyle} />
          </div>
          <Form layout="vertical" onFinish={handleSubmit}>
            <FormItem
              rules={[{ required: true, message: '请输入用户名!' }]}
              className={styles.formItem}
              name="user_name"
              label="用户名"
            >
              <Input
                className={styles.formItemInput}
                size="large"
                placeholder="请输入用户名"
                allowClear
              />
            </FormItem>
            <FormItem
              className={styles.formItem}
              name="password"
              label="密码"
              rules={[{ required: true, message: '请输入密码!' }]}
            >
              <Input
                className={styles.formItemInput}
                size="large"
                type="password"
                placeholder="请输入密码"
                allowClear
              />
            </FormItem>
            <FormItem
              className={styles.formItem}
              name="captcha_code"
              label="验证码"
              rules={[{ required: true, message: '请输入验证码!' }]}
            >
              <Input
                className={styles.formItemInput}
                size="large"
                suffix={
                  <img
                    className={styles.captcha}
                    onClick={() => {
                      fetchCaptcha();
                    }}
                    src={`/web/v1/login/captcha?id=${captcha_id}`}
                    alt="验证码"
                  />
                }
                placeholder="请输入验证码"
              />
            </FormItem>
            <div>
              <Button className={styles.submit} htmlType="submit">
                登录
              </Button>
            </div>
          </Form>
        </div>
      </div>
      <Footer />
    </div>
  );
};

export default Login;
